@@ -405,7 +405,7 @@ class Install(MethodsInterface):
             labels = ["calculate%d" % i for i in range(1, len(efidirs) + 1)]
         else:
             labels = ["calculate"]
-        for efiname, efidir in reversed(zip(labels, efidirs)):
+        for efiname, efidir in reversed(list(zip(labels, efidirs))):
             self._install_grub_uefi(cmd_grub_install, prefix_boot, target,
                                     efidir, efiname)
         # удаляем устаревшие
